@@ -47,10 +47,9 @@ def read_version(f, scheme):
 
 def main():
     import argparse
-    from os.path import dirname, join
     from textwrap import indent
 
-    version_txt = join(dirname(dirname(dirname(__file__))), 'version.txt')
+    version_txt = 'version.txt'
 
     parser = argparse.ArgumentParser(
         description="Version bumper.",
@@ -62,7 +61,7 @@ def main():
 
     parser.add_argument('file', default=version_txt, nargs='?',
                         help="The file containing the version number"
-                        " (defaults to %s)" % version_txt)
+                        " (defaults to “%s”)" % version_txt)
     parser.add_argument('--scheme', default='simple2',
                         choices=['pep440', 'simple2', 'simple3', 'simple4'],
                         help="Scheme to follow, by default 'simple2'")
